@@ -1,13 +1,36 @@
-# ABSTRACT: test that files do not contain soft breakpoints
+=head1 NAME
 
+Test::NoBreakpoints - test that files do not contain soft breakpoints
+
+=head1 SYNOPSIS
+
+ use Test::NoBreakpoints;
+ plan tests => $num_tests;
+ no_breakpoints_ok( $file, 'Contains no soft breakpoints' );
+
+Module authors can include the following in a t/nobreakpoints.t file to add
+such checking to a module distribution:
+
+  use Test::More;
+  eval "use Test::NoBreakpoints 0.10";
+  plan skip_all => "Test::NoBreakpoints 0.10 required for testing" if $@;
+  all_files_no_breakpoints_ok();
+
+=head1 DESCRIPTION
+
+I love soft breakpoints (C<$DB::single = 1>) in the Perl debugger. 
+Unfortunately, I have a habit of putting them in my code during development
+and forgetting to take them out before I upload it to CPAN, necessitating a
+hasty fix/package/bundle cycle followed by much cursing.
+
+Test::NoBreakpoints checks that files contain neither the string
+C<$DB::single = 1> nor C<$DB::signal = 1>.  By adding such a test to all my
+modules, I swear less and presumably lighten the load on the CPAN in some
+small way.
+
+=cut
 
 package Test::NoBreakpoints;
-{
-  $Test::NoBreakpoints::VERSION = '0.14';
-}
-{
-  $Test::NoBreakpoints::DIST = 'Test-NoBreakpoints';
-}
 
 use strict;
 
@@ -18,6 +41,8 @@ use Test::Builder;
 require Exporter;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
+$VERSION = '0.16';
+
 @ISA       = 'Exporter';
 @EXPORT    = qw|
     all_files_no_breakpoints_ok
@@ -148,43 +173,7 @@ sub all_files_no_breakpoints_ok
 1;
 
 
-
-
-=pod
-
-=head1 NAME
-
-Test::NoBreakpoints - test that files do not contain soft breakpoints
-
-=head1 VERSION
-
-version 0.14
-
-=head1 SYNOPSIS
-
- use Test::NoBreakpoints;
- plan tests => $num_tests;
- no_breakpoints_ok( $file, 'Contains no soft breakpoints' );
-
-Module authors can include the following in a t/nobreakpoints.t file to add
-such checking to a module distribution:
-
-  use Test::More;
-  eval "use Test::NoBreakpoints 0.10";
-  plan skip_all => "Test::NoBreakpoints 0.10 required for testing" if $@;
-  all_files_no_breakpoints_ok();
-
-=head1 DESCRIPTION
-
-I love soft breakpoints (C<$DB::single = 1>) in the Perl debugger. 
-Unfortunately, I have a habit of putting them in my code during development
-and forgetting to take them out before I upload it to CPAN, necessitating a
-hasty fix/package/bundle cycle followed by much cursing.
-
-Test::NoBreakpoints checks that files contain neither the string
-C<$DB::single = 1> nor C<$DB::signal = 1>.  By adding such a test to all my
-modules, I swear less and presumably lighten the load on the CPAN in some
-small way.
+__END__
 
 =head1 FUNCTIONS
 
@@ -245,7 +234,7 @@ lexical warning category:
     no warnings 'deprecated';
     no_brkpts_ok(...);
   }
-
+  
 In the next release, the deprecated functions will have to be pulled in via
 an import tag.  In the release after that, they will cease to be.
 
@@ -334,7 +323,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
